
type TUpload = {
  id: string
  size?: number
  offset: number
  metadata?: Record<string, string | null>
  storage?: {
    type: string
    path: string
    bucket?: string
  }
  creation_date?: string
}

export class Upload {
  id: TUpload['id']
  metadata: TUpload['metadata']
  size: TUpload['size']
  offset: TUpload['offset']
  creation_date: TUpload['creation_date']
  storage: TUpload['storage']

  constructor(upload: TUpload) {
    // 检查ID是否存在，不存在则抛出错误
    if (!upload.id) {
      throw new Error('[File] constructor must be given an ID')
    }

    // 初始化属性
    this.id = upload.id
    this.size = upload.size
    this.offset = upload.offset
    this.metadata = upload.metadata
    this.storage = upload.storage

    // 如果未提供创建日期，则设置为当前时间
    this.creation_date = upload.creation_date ?? new Date().toISOString()
  }

  get sizeIsDeferred(): boolean {
    return this.size === undefined
  }
}
